@@ -50,8 +50,6 @@ function mapUbuntuNameToDep {
   esac
 }
 
-GET="scp ftpubuntu@ftpmaster.kde.org:/home/ftpubuntu"
-
 clean_dld=1
 subset=""
 
@@ -77,13 +75,18 @@ case ${WDIR##*/} in
     cd ..;;
   "build" )
     cd ..;;
-  "kubuntu-kde-l10n-common" )
+  "kde-l10n-common" )
     ;;
 esac
 
+if ! source debian/config ; then
+    echo "could not source config!!"
+    exit 1
+fi
+
 if [ -e build ]; then
   echo "A already existing build/ directory was found, which indicates that there was a build done earlier."
-  echo "Note: you can also run this script with -ncd to preserve only the tar.bz2 files from build/."
+  echo "Note: you can also run this script with -ncd to preserve only the tar.xz files from build/."
   echo "Do you REALLY REALLY want to mess with the current build dir? (y/n)"
   read -e reply
   if [[ $reply != "y" ]]; then
@@ -95,7 +98,7 @@ fi
 # clean build dir
 if [ $clean_dld -eq 0 ]; then
   find build/* -maxdepth 0 | grep -v build-area | xargs rm -rfv
-  find build/build-area/* -maxdepth 0 | grep -v ".tar.bz2" | xargs rm -rfv
+  find build/build-area/* -maxdepth 0 | grep -v ".tar.xz" | xargs rm -rfv
 else
   rm -rvf build
   mkdir build
@@ -104,8 +107,6 @@ fi
 cd build
 WDIR=`pwd`
 
-BRANCH="lp:~kubuntu-packagers/kubuntu-packaging/kde-l10n-common-natty-archive"
-CO="common"
 BOILERPLATE="# ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! !#\n# DO NOT EVEN THINK ABOUT CHANGING THIS FILE DIRECTLY! ! ! !\n# PLEASE USE THE BZR BRANCH AS SEEN IN debian\/control\n# MAKE YOUR CHANGES THERE AND THEN RUN debian\/build-l10n.sh\n# kthxbai :)\n################################################################################\n################################################################################\n################################################################################\n################################################################################"
 
 if [[ `bzr revno` != `bzr revno ${BRANCH}` ]]; then
@@ -117,6 +118,7 @@ fi
 
 mkdir build-area
 bzr branch $BRANCH $CO
+bzr branch $LANG_PACK_BRANCH $CO-langpack
 
 cd $CO
 VERSION=`dpkg-parsechangelog | sed -ne 's/^Version: \(\([0-9]\+\):\)\?\(.*\)-.*/\3/p'`
@@ -133,20 +135,20 @@ cd build-area
 if [ $clean_dld -ne 0 ]; then
   if [[ "$subset" == "" ]]; then
     # get all
-    $GET/stable/${KDEVERSION}/src/kde-l10n/kde-l10n-*.tar.bz2 .
+    $GET/${TYPE}/${KDEVERSION}/src/kde-l10n/kde-l10n-*.tar.xz .
   else
     # only get subset
     for pkg in $subset; do
-      $GET/stable/${KDEVERSION}/src/kde-l10n/kde-l10n-$pkg-*.tar.bz2 .
+      $GET/${TYPE}/${KDEVERSION}/src/kde-l10n/kde-l10n-$pkg-*.tar.xz .
     done
   fi
 fi
 
-for tfile in `ls kde-l10n-*.tar.bz2`; do
+for tfile in `ls kde-l10n-*.tar.xz`; do
   cd $WDIR
   cd build-area
 
-  if [[ $tfile =~ kde-l10n-(.*)-$KDEVERSION.tar.bz2 ]]; then
+  if [[ $tfile =~ kde-l10n-(.*)-$KDEVERSION.tar.xz ]]; then
     kdecode=${BASH_REMATCH[1]}
 
     # set mappings
@@ -157,10 +159,10 @@ for tfile in `ls kde-l10n-*.tar.bz2`; do
     mapUbuntuNameToDep ubuntudep
 
     # remove any left overs from previous runs
-    rm -r kde-l10n-${ubuntucode}_${VERSION}.orig.tar.bz2
+    rm -r kde-l10n-${ubuntucode}_${VERSION}.orig.tar.xz
 
-    ln -s $tfile kde-l10n-${ubuntucode}_${VERSION}.orig.tar.bz2
-    tar xf kde-l10n-${ubuntucode}_${VERSION}.orig.tar.bz2
+    ln -s $tfile kde-l10n-${ubuntucode}_${VERSION}.orig.tar.xz
+    tar xf kde-l10n-${ubuntucode}_${VERSION}.orig.tar.xz
 
     i=0
     while read line; do
@@ -194,6 +196,43 @@ for tfile in `ls kde-l10n-*.tar.bz2`; do
 ################################################################################/$BOILERPLATE/g" $dfile
     done
 
-    bzr-buildpackage -S --builder "make -f debian/rules get-desktop && dpkg-buildpackage -S -us -uc"
+    bzr-buildpackage -S --builder "dpkg-buildpackage -S -us -uc"
+    cd ../..
+
+    bzr branch $CO-langpack language-pack-kde-$ubuntudep
+
+    cd language-pack-kde-$ubuntudep/debian/
+    for dfile in `ls`; do
+      sed -i "s/id/$ubuntudep/g" $dfile
+      sed -i "s/id/$ubuntucode/g" $dfile
+      sed -i "s/id/$kdecode/g" $dfile
+      sed -i "s/Indonesian/$kdename/g" $dfile
+      sed -i "s/# ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! !#
+# DO NOT EVEN THINK ABOUT CHANGING THIS FILE DIRECTLY! ! ! !
+# PLEASE USE THE BZR BRANCH AS SEEN IN debian/control
+# MAKE YOUR CHANGES THERE AND THEN RUN debian/build-l10n.sh
+# kthxbai :)
+################################################################################
+################################################################################
+################################################################################
+################################################################################/$BOILERPLATE/g" $dfile
+    done
+
+    CALLIGRA=`apt-cache policy calligra-l10n-${kdecode}`
+    if [[ -n $CALLIGRA ]]; then 
+        sed -i "s/^Depends:.*/&, calligra-l10n-${kdecode}/" control
+    fi
+
+    if [[ $ubuntudep != $kdecode ]]; then
+        echo $ubuntudep NOT $kdecode
+        sed -i "s/^Depends:.*/&, kde-l10n-${ubuntucode}/" control
+
+        CALLIGRA=`apt-cache policy calligra-l10n-${ubuntucode}`
+        if [[ -n $CALLIGRA ]]; then 
+           sed -i "s/^Depends:.*/&, calligra-l10n-${ubuntucode}/" control
+        fi
+    fi
+
+    bzr-buildpackage -S --builder "dpkg-buildpackage -S -us -uc"
   fi
 done
